
XEP-0258: Security Labels in XMPP
=================================

.. module:: slixmpp.plugins.xep_0258

.. autoclass:: XEP_0258
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0258.stanza
    :members:
    :undoc-members:

